@@ -15,12 +15,20 @@ class MarkerView(View):
 
     def get(self, request, template=None, *args, **kwargs):
 
+        text_x = self.request.GET.get("text_x")
+        if text_x and text_x.isdigit():
+            text_x = int(text_x)
+
+        text_y = self.request.GET.get("text_y")
+        if text_y and text_y.isdigit():
+            text_y = int(text_y)
+
         try:
             marker = Marker(
                 template=template,
                 hue=self._get_float("hue", 0),
                 text=request.GET.get("text",""),
-                text_position=(self._get_int("text_x", 0), self._get_int("text_y", 0)),
+                text_position=(text_x, text_y),
                 text_size=self._get_int("text_size", 11),
                 text_colour=self.request.GET.get("text_colour", "000000"),
                 opacity=self._get_float("opacity", 1)
